@@ -1,7 +1,7 @@
 package App::ProgUtils;
 
-our $DATE = '2014-08-16'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2014-09-16'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -58,27 +58,26 @@ App::ProgUtils - Command line to manipulate programs in PATH
 
 =head1 VERSION
 
-This document describes version 0.11 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2014-08-16.
+This document describes version 0.12 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2014-09-16.
 
 =head1 SYNOPSIS
 
 This distribution provides the following command-line utilities:
 
- progless
  progedit
+ progless
  progman
+ progpath
 
 =head1 SEE ALSO
 
-B<which>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-ProgUtils>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-ProgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-ProgUtils>.
 
 =head1 BUGS
 
@@ -90,11 +89,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
